@@ -623,13 +623,22 @@ class BayesModelBuilder:
             src_dict[dest].append(src)
 
         node_list = list(set(node_list))
+        print('node_list',node_list)
 
         for node in node_list:
             self.add_variable("g_{}".format(node), "normal", 0, 1)  # gain
             self.add_variable("b_{}".format(node), "normal", 0, 1)  # gain
             self.add_variable("s_{}".format(node), "exponential", 0, 1)  # gain
-            self.add_variable("{}[0]".format(node), "normal", 0, 1)
-        
+            
+            if hasattr(self, 'input_list') and self.input_list is not None:
+                if node in self.input_list:
+                    pass
+                else:
+                    self.add_variable("{}[0]".format(node), "normal", 0, 1)
+            else:
+                self.add_variable("{}[0]".format(node), "normal", 0, 1)
+
+        print('src_dict', src_dict)
         for dest in src_dict.keys():
             src_list = src_dict[dest]
             for src in src_list:
@@ -654,7 +663,7 @@ class BayesModelBuilder:
                     term_str = 'g_{}*{}[{}-1] + b_{}'.format(dest, dest, index, dest)
             else:
                 if len(term_list) > 0:
-                    term_str = '({}) + b_{}'.format(dest, dest, index, " + ".join(term_list), dest)
+                    term_str = '({}) + b_{}'.format(" + ".join(term_list), dest)
                 else:
                     term_str = 'b_{}'.format(dest)
             self.add_variable(
